@@ -5,18 +5,20 @@ package Pod::Simple::Wiki::Moinmoin;
 # Pod::Simple::Wiki::Moinmoin - A class for creating Pod to Moinmoin filters.
 #
 #
-# Copyright 2003-2008, John McNamara, jmcnamara@cpan.org
+# Copyright 2003-2012, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
 
+# perltidy with the following options: -mbl=2 -pt=0 -nola
+
 use Pod::Simple::Wiki;
 use strict;
 use vars qw(@ISA $VERSION);
 
 
 @ISA     = qw(Pod::Simple::Wiki);
-$VERSION = '0.08';
+$VERSION = '0.17';
 
 
 ###############################################################################
@@ -24,24 +26,24 @@ $VERSION = '0.08';
 # The tag to wiki mappings.
 #
 my $tags = {
-            '<b>'    => "'''",
-            '</b>'   => "'''",
-            '<i>'    => "''",
-            '</i>'   => "''",
-            '<tt>'   => '`',
-            '</tt>'  => '`',
-            '<pre>'  => "\n{{{\n",
-            '</pre>' => "\n}}}\n",
+    '<b>'    => "'''",
+    '</b>'   => "'''",
+    '<i>'    => "''",
+    '</i>'   => "''",
+    '<tt>'   => '`',
+    '</tt>'  => '`',
+    '<pre>'  => "\n{{{\n",
+    '</pre>' => "\n}}}\n",
 
-            '<h1>'   => "\n== ",
-            '</h1>'  => " ==\n\n",
-            '<h2>'   => "\n=== ",
-            '</h2>'  => " ===\n\n",
-            '<h3>'   => "\n==== ",
-            '</h3>'  => " ====\n\n",
-            '<h4>'   => "\n===== ",
-            '</h4>'  => " =====\n\n",
-           };
+    '<h1>'  => "\n== ",
+    '</h1>' => " ==\n\n",
+    '<h2>'  => "\n=== ",
+    '</h2>' => " ===\n\n",
+    '<h3>'  => "\n==== ",
+    '</h3>' => " ====\n\n",
+    '<h4>'  => "\n===== ",
+    '</h4>' => " =====\n\n",
+};
 
 
 ###############################################################################
@@ -52,11 +54,11 @@ my $tags = {
 #
 sub new {
 
-    my $class                   = shift;
-    my $self                    = Pod::Simple::Wiki->new('wiki', @_);
-       $self->{_tags}           = $tags;
+    my $class = shift;
+    my $self = Pod::Simple::Wiki->new( 'wiki', @_ );
+    $self->{_tags} = $tags;
 
-    bless  $self, $class;
+    bless $self, $class;
     return $self;
 }
 
@@ -74,14 +76,14 @@ sub _indent_item {
     my $item_param   = $_[1];
     my $indent_level = $self->{_item_indent};
 
-    if    ($item_type eq 'bullet') {
-         $self->_append(' ' x $indent_level . "* ");
+    if ( $item_type eq 'bullet' ) {
+        $self->_append( ' ' x $indent_level . "* " );
     }
-    elsif ($item_type eq 'number') {
-         $self->_append(' ' x $indent_level . "1. ");
+    elsif ( $item_type eq 'number' ) {
+        $self->_append( ' ' x $indent_level . "1. " );
     }
-    elsif ($item_type eq 'text') {
-         $self->_append(' ' x $indent_level);
+    elsif ( $item_type eq 'text' ) {
+        $self->_append( ' ' x $indent_level );
     }
 
     $self->{_moinmoin_list} = 1;
@@ -119,8 +121,10 @@ sub _handle_text {
 # Text     lists
 # Block    lists
 #
-sub _end_item_text     {$_[0]->_output(":: ");
-                        $_[0]->{_moinmoin_list} = 0;}
+sub _end_item_text {
+    $_[0]->_output( ":: " );
+    $_[0]->{_moinmoin_list} = 0;
+}
 
 ###############################################################################
 #
@@ -133,21 +137,21 @@ sub _start_Para {
     my $self         = shift;
     my $indent_level = $self->{_item_indent};
 
-    if ($self->{_in_over_block}) {
-        $self->_append(' ' x $indent_level);
+    if ( $self->{_in_over_block} ) {
+        $self->_append( ' ' x $indent_level );
     }
 
-    if ($self->{_moinmoin_list}) {
-        if (not $self->{_in_over_text} and $self->{_moinmoin_list} == 1) {
-             $self->_append("\n");
+    if ( $self->{_moinmoin_list} ) {
+        if ( not $self->{_in_over_text} and $self->{_moinmoin_list} == 1 ) {
+            $self->_append( "\n" );
         }
 
-        if ($self->{_in_over_text} and $self->{_moinmoin_list} == 2) {
-             $self->_append("\n");
+        if ( $self->{_in_over_text} and $self->{_moinmoin_list} == 2 ) {
+            $self->_append( "\n" );
         }
 
-        if (not ($self->{_in_over_text} and $self->{_moinmoin_list} == 1)) {
-             $self->_append(' ' x $indent_level);
+        if ( not( $self->{_in_over_text} and $self->{_moinmoin_list} == 1 ) ) {
+            $self->_append( ' ' x $indent_level );
         }
 
         $self->{_moinmoin_list}++;
@@ -191,7 +195,7 @@ The C<Pod::Simple::Wiki::Moinmoin> module is used for converting Pod text to Wik
 
 Pod (Plain Old Documentation) is a simple markup language used for writing Perl documentation.
 
-For an introduction to Moinmoin see: http://moinmoin.wikiwikiweb.de/
+For an introduction to Moinmoin see: L<http://moinmoin.wikiwikiweb.de/>
 
 This module isn't generally invoked directly. Instead it is called via C<Pod::Simple::Wiki>. See the L<Pod::Simple::Wiki> and L<pod2wiki> documentation for more information.
 
@@ -223,6 +227,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MMIII-MMVIII, John McNamara.
+MMIII-MMXV, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
